package com.ruoyi.jarvis.mapper;

import java.util.List;
import com.ruoyi.jarvis.domain.XbMessageItem;

/**
 * 线报消息项Mapper接口
 *
 * @author ruoyi
 */
public interface XbMessageItemMapper
{
    /**
     * 查询线报消息项
     *
     * @param id 线报消息项主键
     * @return 线报消息项
     */
    public XbMessageItem selectXbMessageItemById(Integer id);

    /**
     * 查询线报消息项列表
     *
     * @param xbMessageItem 线报消息项
     * @return 线报消息项集合
     */
    public List<XbMessageItem> selectXbMessageItemList(XbMessageItem xbMessageItem);

    /**
     * 新增线报消息项
     *
     * @param xbMessageItem 线报消息项
     * @return 结果
     */
    public int insertXbMessageItem(XbMessageItem xbMessageItem);

    /**
     * 修改线报消息项
     *
     * @param xbMessageItem 线报消息项
     * @return 结果
     */
    public int updateXbMessageItem(XbMessageItem xbMessageItem);

    /**
     * 删除线报消息项
     *
     * @param id 线报消息项主键
     * @return 结果
     */
    public int deleteXbMessageItemById(Integer id);

    /**
     * 批量删除线报消息项
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXbMessageItemByIds(Integer[] ids);
}
